You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@sling.apache.org by kw...@apache.org on 2021/05/17 10:26:27 UTC

[sling-org-apache-sling-feature-cpconverter] branch master updated: SLING-10382 fix Sling prefix URL

This is an automated email from the ASF dual-hosted git repository.

kwin pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/sling-org-apache-sling-feature-cpconverter.git


The following commit(s) were added to refs/heads/master by this push:
     new 0e95a5d  SLING-10382 fix Sling prefix URL
0e95a5d is described below

commit 0e95a5d4bb5975f4163eaa21371dad406f501aa9
Author: Konrad Windszus <kw...@apache.org>
AuthorDate: Mon May 17 12:26:19 2021 +0200

    SLING-10382 fix Sling prefix URL
---
 .../apache/sling/feature/cpconverter/vltpkg/JcrNamespaceRegistry.java | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/main/java/org/apache/sling/feature/cpconverter/vltpkg/JcrNamespaceRegistry.java b/src/main/java/org/apache/sling/feature/cpconverter/vltpkg/JcrNamespaceRegistry.java
index 035ffbc..00021c3 100644
--- a/src/main/java/org/apache/sling/feature/cpconverter/vltpkg/JcrNamespaceRegistry.java
+++ b/src/main/java/org/apache/sling/feature/cpconverter/vltpkg/JcrNamespaceRegistry.java
@@ -46,8 +46,8 @@ public class JcrNamespaceRegistry implements NamespaceRegistry, NamespaceResolve
         prefixUriMapping.put(PREFIX_MIX, NAMESPACE_MIX);
         prefixUriMapping.put(PREFIX_NT, NAMESPACE_NT);
         prefixUriMapping.put(PREFIX_XML, NAMESPACE_XML);
-        // referencing from org.apache.sling.api.SlingConstants would require an additional dependency
-        prefixUriMapping.put("sling", "http://sling.apache.org/");
+        // referencing from org.apache.sling.jcr.resource.api.JcrResourceConstants.SLING_NAMESPACE_URI would require an additional dependency
+        prefixUriMapping.put("sling", "http://sling.apache.org/jcr/sling/1.0");
         registeredCndSystemIds = new ArrayList<>();
     }